/*	Copyright (C) 2018-2024 Martin Guy <martinwguy@gmail.com>
 *
 *	This program is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation, either version 3 of the License, or
 *	(at your option) any later version.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program; if not, write to the Free Software
 *	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

/*
 * spettro.c - Portability functions. main() is in main.c
 */

/* Don't include spettro.h because it includes SDL.h which contains a load of
 * HAVE_* defines that may conflict with configure.h
 */
#include "configure.h"

#if !HAVE_STRDUP
#include <string.h>
#include <stddef.h>
#include "alloc.h"

char *
strdup(const char *s)
{
    char *new = Malloc(strlen(s) + 1);

    strcpy(new, s);

    return new;
}
#endif

#if !HAVE_STRCHR
char *
strchr(const char *s, const char c)
{
    char *p;

    for (p=s; *p; p++)
        if (*p == c) return p;

    return NULL;
}
#endif
